@@ -17,7 +17,8 @@ def is_successful(xml):
 
 
 def get_data_field(xml, field):
-    return str(_get_xml_field(xml, "Data", data_field=field))
+    value = _get_xml_field(xml, "Data", data_field=field)
+    return value or ""
 
 
 def get_data(xml):
