@@ -1,5 +1,6 @@
 import os
 import subprocess
+import time
 import logging
 
 import requests
@@ -497,7 +498,8 @@ class LoadMaster(HttpClient):
     def backup(self, location='backups'):
         if not os.path.exists(location):
             os.makedirs(location)
-        file_name = os.path.join(location, "{}.backup".format(self.ip_address))
+        file_name = os.path.join(location, "{}_{}.backup".format(
+            self.ip_address, time.strftime("%Y-%m-%d_%H:%M:%S")))
 
         with open(file_name, 'wb') as file:
             cmd = self._get_curl_command_list('backup')
